local L = AceLibrary("AceLocale-2.2"):new("Omen")
local SML = AceLibrary("SharedMedia-1.0")
local SML_statusbar = SML:List("statusbar")

local formatOptions = {"%2.0f", "%2.1f", "%2.2f"}

local options = {
	type='group',
	args = {
		toggle = {
			type = "execute",
			desc = L["Toggle Omen"],
			name = L["Toggle Omen"],
			func = "Toggle",
			order = 102
		},
		toggle = {
			type = "toggle",
			name = L["Active When Solo"],
			desc = L["Activate Omen when solo or in a battlegroups (testing purposes only)"],
			get = function()
				return Omen.db.profile.ActivateSolo
			end,
			set = function(v)
				Omen.db.profile.ActivateSolo = v
				AceLibrary("Threat-1.0"):RequestActiveOnSolo(v)
			end
		},		
		bars = {
			type = "group",
			name = L["Bars"],
			desc = L["Bars"],
			args = {
				animateBars = {
					type = "toggle",
					desc = L["Animate Bars"],
					name = L["Animate Bars"],
					get = function()
						return Omen.db.profile.AnimateBars
					end,
					set = function(t)
						Omen.db.profile.AnimateBars = t
					end
				},
				--[[ 
				growUp = {
					type = "toggle",
					desc = L["Grow Upwards"],
					name = L["Grow Upwards"],
					get = function()
						return Omen.db.profile.GrowUp
					end,
					set = function(t)
						Omen.db.profile.GrowUp = t
					end
				},				
				]]--
				stretchBarTextures = {
					type = "toggle",
					desc = L["Stretch Bar Textures"],
					name = L["Stretch Bar Textures"],
					get = function()
						return Omen.db.profile.StretchBarTextures
					end,
					set = function(t)
						Omen.db.profile.StretchBarTextures = t
						if t then
							for k,v in pairs(Omen.bars) do
								v.tex:SetTexCoord(0, 1, 0, 1)
							end
						end
					end
				},
				maxBars = {
					type = "range",
					name = L["Number of bars"],
					desc = L["Number of bars"],
					step = 1,
					min = 1,
					max = 40,
					isPercent = false,
					get = function()
						return Omen.db.profile.MaxBars
					end,
					set = function(v)
						Omen.db.profile.MaxBars = v
					end
				},
				barHeight = {
					type = "range",
					name = L["Bar Height"],
					desc = L["Bar Height"],
					step = 1,
					min = 10,
					max = 100,
					isPercent = false,
					get = function()
					return Omen.db.profile.BarHeight
					end,
					set = function(h)
						Omen.db.profile.BarHeight = h
						local barCt = 0
						for k, v in pairs(Omen.bars) do
							v:SetHeight(h)
							if v.threatVal > 0 then
								barCt = barCt + 1
							end
						end
						Omen.Anchor:SetHeight(h * max(0,barCt) + Omen.barsOffset + 5)
					end
				},
				barTexture = {
					type = "text",
					name = L["Bar Texture"],
					desc = L["Bar Texture"],
					get = function() return Omen.db.profile.BarTexture end,
					set = function(tex)
						Omen.db.profile.BarTexture = tex
						for k, v in pairs(Omen.bars) do
							v.tex:SetTexture(SML:Fetch("statusbar", tex))
						end
					end,
					validate = SML_statusbar,
					usage = "<texture>",
				},
				playerBarColor = {
					type = "color",
					hasAlpha = false,
					name = L["Player's Bar Color"],
					desc = L["Player's Bar Color"],
					disabled = function()
						return Omen.db.profile.UseCustomBarColors == false
					end,
					get = function()
						local f = Omen.db.profile.PlayerBarColor
						return f.r, f.g, f.b, f.a
					end,
					set = function(r,g,b,a)
						local f = Omen.db.profile.PlayerBarColor
						f.r, f.g, f.b, f.a = r, g, b, a
						Omen.bars[UnitName("player")].tex:SetVertexColor(f.r, f.g, f.b)
					end
				},
				usePlayerBarColor = {
					type = "toggle",
					desc = L["Use Custom Bar Color"],
					name = L["Use Custom Bar Color"],
					get = function()
						return Omen.db.profile.UseCustomBarColors
					end,
					set = function(t)
						Omen.db.profile.UseCustomBarColors = t
					end
				}				
			}
		},
		tps = {
			type = "group",
			name = L["Threat Per Second"],
			desc = L["Threat Per Second"],
			args = {
				tpsUpdateFrequency = {
					type = "range",
					name = L["Update Frequency"],
					desc = L["Update Frequency"],
					step = 0.05,
					min = 0.05,
					max = 2.0,
					isPercent = false,
					get = function()
						return Omen.db.profile.TPSUpdateFrequency
					end,
					set = function(v)
						Omen.db.profile.TPSUpdateFrequency = v
						Omen:DisableTPSUpdate()
						Omen:EnableTPSUpdate()
					end
				},
				tpsWindow = {
					type = "range",
					name = L["p1"],
					desc = L["p1 speed description"],
					step = 0.005,
					min = 0.900,
					max = 0.999,
					isPercent = false,
					get = function()
						return Omen.db.profile.TPSWindow
					end,
					set = function(v)
						Omen.db.profile.TPSWindow = v
					end
				},
				showTPS = {
					type = "toggle",
					desc = L["Show TPS"],
					name = L["Show TPS"],
					get = function()
						return Omen.db.profile.ShowTPS
					end,
					set = function(t)
						Omen.db.profile.ShowTPS = t
						if t then
							Omen.Anchor.tpsLabel:Show()
						else
							Omen.Anchor.tpsLabel:Hide()
						end
						for k,v in pairs(Omen.bars) do
							if not t then
								v.threatPerSec:Hide()
							else
								v.threatPerSec:Show()
							end
						end
					end
				},
			}
		},
		backdropColor = {
			type = "color",
			hasAlpha = true,
			name = L["Background Color"],
			desc = L["Background Color"],
			get = function()
				local f = Omen.db.profile.BackdropColor
				return f.r, f.g, f.b, f.a
			end,
			set = function(r,g,b,a)
				local f = Omen.db.profile.BackdropColor
				f.r, f.g, f.b, f.a = r, g, b, a
				Omen.Anchor:SetBackdropColor(r, g, b, a)
			end
		},
		backdropBorderColor = {
			type = "color",
			hasAlpha = true,
			name = L["Border Color"],
			desc = L["Border Color"],
			get = function()
				local f = Omen.db.profile.BorderColor
				return f.r, f.g, f.b, f.a
			end,
			set = function(r,g,b,a)
				local f = Omen.db.profile.BorderColor
				f.r, f.g, f.b, f.a = r, g, b, a
				Omen.Anchor:SetBackdropBorderColor(r, g, b, a)
			end
		}		
	}
}

Omen.OnMenuRequest = options
Omen:RegisterChatCommand({"/omen"}, options, "OMEN")